@@ -108,8 +108,9 @@ class DiagramDraw(object):
     def _draw_background(self):
         # Draw node groups.
         for group in self.groups:
-            box = self.metrics.group(group).marginbox
-            self.drawer.rectangle(box, fill=group.color, filter='blur')
+            if group.shape == 'box':
+                box = self.metrics.group(group).marginbox
+                self.drawer.rectangle(box, fill=group.color, filter='blur')
 
         # Drop node shadows.
         for node in self.nodes:
@@ -130,22 +131,28 @@ class DiagramDraw(object):
         for edge in self.edges:
             self.edge(edge)
 
+        for group in self.groups:
+            if group.shape == 'line':
+                box = self.metrics.group(group).marginbox
+                self.drawer.rectangle(box, fill='none', outline=group.color,
+                                      style=group.style, thick=group.thick)
+
     def node(self, node, **kwargs):
         r = noderenderer.get(node.shape)
         shape = r(node, self.metrics)
-        shape.render(self.drawer, self.format,
-                     fill=self.fill, outline=self.diagram.linecolor,
+        shape.render(self.drawer, self.format, fill=self.fill,
                      badgeFill=self.badgeFill)
 
     def group_label(self, group):
         m = self.metrics.group(group)
+        fontsize = self.metrics.fontsize_for(group)
 
         if group.label and not group.separated:
             self.drawer.textarea(m.grouplabelbox, group.label,
-                                 fill=group.textcolor, fontsize=group.fontsize)
+                                 fill=group.textcolor, fontsize=fontsize)
         elif group.label:
-            self.drawer.textarea(m.corebox, group.label, fill=group.textcolor,
-                                 fontsize=group.fontsize)
+            self.drawer.textarea(m.corebox, group.label,
+                                 fill=group.textcolor, fontsize=fontsize)
 
     def edge(self, edge):
         metrics = self.metrics.edge(edge)
@@ -161,9 +168,10 @@ class DiagramDraw(object):
                 self.drawer.polygon(head, outline=edge.color, fill=edge.color)
 
         if edge.label:
+            fontsize = self.metrics.fontsize_for(edge)
             self.drawer.textarea(metrics.labelbox, edge.label,
                                  fill=edge.textcolor, outline=self.fill,
-                                 fontsize=edge.fontsize)
+                                 fontsize=fontsize)
 
     def save(self, size=None):
         return self.drawer.save(self.filename, size, self.format)
