@@ -123,7 +123,7 @@ class DiagramMetrics(object):
     node_padding = 4
     line_spacing = 2
     shadow_offset = XY(3, 6)
-    font = 11
+    font = None
     fontsize = 11
     page_margin = XY(0, 0)
     page_padding = [0, 0, 0, 0]
@@ -151,8 +151,8 @@ class DiagramMetrics(object):
         if fontname is not None:
             self.font = fontname
 
-        if diagram.fontsize is not None:
-            self.fontsize = diagram.fontsize
+        if diagram.default_fontsize is not None:
+            self.fontsize = diagram.default_fontsize
 
         if diagram.page_padding is not None:
             self.page_padding = diagram.page_padding
@@ -192,8 +192,10 @@ class DiagramMetrics(object):
 
     def textsize(self, string, width=65535, fontsize=None):
         try:
-            if self.format == 'PDF':
-                from utils.PDFTextFolder import PILTextFolder as TextFolder
+            if self.font is None:
+                from utils.TextFolder import TextFolder
+            elif self.format == 'PDF':
+                from utils.PDFTextFolder import PDFTextFolder as TextFolder
             else:
                 from utils.PILTextFolder import PILTextFolder as TextFolder
         except ImportError:
@@ -231,6 +233,12 @@ class DiagramMetrics(object):
             else:
                 return PortraitEdgeMetrics(edge, self)
 
+    def fontsize_for(self, element):
+        if hasattr(element, 'fontsize') and element.fontsize:
+            return element.fontsize
+        else:
+            return self.fontsize
+
     def pagesize(self, width, height):
         return self.spreadsheet.pagesize(width, height)
 
