@@ -3,22 +3,12 @@
 import os
 import sys
 import tempfile
+from utils import argv_wrapper
 from nose.tools import raises, ok_, eq_
 from blockdiag.command import parse_option, detectfont
 
 
-def replace_argv(func):
-    def test():
-        try:
-            argv = sys.argv
-            func()
-        finally:
-            sys.argv = argv
-
-    return test
-
-
-@replace_argv
+@argv_wrapper
 def type_option_test():
     sys.argv = ['', '-Tsvg', 'input.diag']
     parse_option()
@@ -37,13 +27,13 @@ def type_option_test():
 
 
 @raises(RuntimeError)
-@replace_argv
+@argv_wrapper
 def invalid_type_option_test():
     sys.argv = ['', '-Tsvgz', 'input.diag']
     (options, args) = parse_option()
 
 
-@replace_argv
+@argv_wrapper
 def separate_option_test():
     sys.argv = ['', '-Tsvg', '--separate', 'input.diag']
     (options, args) = parse_option()
@@ -55,27 +45,27 @@ def separate_option_test():
     (options, args) = parse_option()
 
 
-@replace_argv
+@argv_wrapper
 def svg_nodoctype_option_test():
     sys.argv = ['', '-Tsvg', '--nodoctype', 'input.diag']
     (options, args) = parse_option()
 
 
 @raises(RuntimeError)
-@replace_argv
+@argv_wrapper
 def png_nodoctype_option_test():
     sys.argv = ['', '-Tpng', '--nodoctype', 'input.diag']
     (options, args) = parse_option()
 
 
 @raises(RuntimeError)
-@replace_argv
+@argv_wrapper
 def pdf_nodoctype_option_test():
     sys.argv = ['', '-Tpdf', '--nodoctype', 'input.diag']
     (options, args) = parse_option()
 
 
-@replace_argv
+@argv_wrapper
 def config_option_test():
     tmp = tempfile.mkstemp()
     sys.argv = ['', '-c', tmp[1], 'input.diag']
@@ -86,7 +76,7 @@ def config_option_test():
 
 
 @raises(RuntimeError)
-@replace_argv
+@argv_wrapper
 def invalid_config_option_test():
     tmp = tempfile.mkstemp()
     os.close(tmp[0])
@@ -97,7 +87,7 @@ def invalid_config_option_test():
 
 
 @raises(RuntimeError)
-@replace_argv
+@argv_wrapper
 def invalid_dir_config_option_test():
     try:
         tmp = tempfile.mkdtemp()
@@ -108,7 +98,7 @@ def invalid_dir_config_option_test():
         os.rmdir(tmp)
 
 
-@replace_argv
+@argv_wrapper
 def config_option_fontpath_test():
     tmp = tempfile.mkstemp()
     os.fdopen(tmp[0], 'wt').write('[blockdiag]\nfontpath = /path/to/font\n')
@@ -121,14 +111,14 @@ def config_option_fontpath_test():
 
 
 @raises(RuntimeError)
-@replace_argv
+@argv_wrapper
 def not_exist_font_config_option_test():
     sys.argv = ['', '-f', '/font_is_not_exist', 'input.diag']
     (options, args) = parse_option()
     detectfont(options)
 
 
-@replace_argv
+@argv_wrapper
 def auto_font_detection_test():
     sys.argv = ['', 'input.diag']
     (options, args) = parse_option()
